Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: ui/message_center/notification_delegate.h

Issue 2870283002: Move message_center::CustomNotificationView to arc::ArcNotificationView (Closed)
Patch Set: Addressed comment Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/message_center/BUILD.gn ('k') | ui/message_center/notification_delegate_views.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/message_center/notification_delegate.h
diff --git a/ui/message_center/notification_delegate.h b/ui/message_center/notification_delegate.h
index a66d3760e690d8c03458ee9266f1be928a03269c..dd6f4cd2df9836f68e5b996a5ad2297f4a75d2b0 100644
--- a/ui/message_center/notification_delegate.h
+++ b/ui/message_center/notification_delegate.h
@@ -14,12 +14,12 @@
#include "base/strings/string16.h"
#include "ui/message_center/message_center_export.h"
-#if defined(TOOLKIT_VIEWS) && !defined(OS_MACOSX)
-#include "ui/message_center/views/custom_notification_content_view_delegate.h"
-#endif
-
namespace message_center {
+class MessageCenterController;
+class MessageView;
+class Notification;
+
// Delegate for a notification. This class has two roles: to implement callback
// methods for notification, and to provide an identity of the associated
// notification.
@@ -56,9 +56,11 @@ class MESSAGE_CENTER_EXPORT NotificationDelegate
virtual bool ShouldDisplaySettingsButton();
#if defined(TOOLKIT_VIEWS) && !defined(OS_MACOSX)
- // To be called to construct the contents view of a popup for notifications
- // whose type is NOTIFICATION_TYPE_CUSTOM.
- virtual std::unique_ptr<CustomContent> CreateCustomContent();
+ // To be called to construct the message view for notifications whose type is
+ // NOTIFICATION_TYPE_CUSTOM.
+ virtual std::unique_ptr<MessageView> CreateCustomMessageView(
+ MessageCenterController* controller,
+ const Notification& notification);
#endif
// Indicates whether this notification should be displayed when there is
« no previous file with comments | « ui/message_center/BUILD.gn ('k') | ui/message_center/notification_delegate_views.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698